@@ -49,7 +49,7 @@ class URLsMixin(URLsMixinREST):
     """For backwards compatibility."""
     def __init__(self, *args, **kwargs):
         warnings.warn(
-            'URLsMixin and URLsTestCase are deprecated; use URLsMixinREST and URLsTestCaseREST instead.',
+            'URLsMixin is deprecated; use URLsMixinREST instead.',
             DeprecationWarning)
         super(URLsMixin, self).__init__(*args, **kwargs)
 
